summaryrefslogtreecommitdiff
path: root/src/mongo/db/storage/oplog_hack.h
diff options
context:
space:
mode:
authorMathias Stearn <mathias@10gen.com>2014-11-26 15:04:26 -0500
committerMathias Stearn <mathias@10gen.com>2014-11-26 15:15:59 -0500
commit16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8 (patch)
tree2d9f056acf8f1b9b2e943f82e315bdf019475a38 /src/mongo/db/storage/oplog_hack.h
parentcb5cab88761d9aca75e064665cce89f579c69e36 (diff)
downloadmongo-16a8ef7ad60d498b69bdc0ad5cbca44757d16fd8.tar.gz
SERVER-13679 Replace DiskLoc with RecordId outside of MMAPv1
Operations: sed -i -e 's/\<DiskLoc\>/RecordId/g' sed -i -e 's/\<DiskLocs\>/RecordIds/g' sed -i -e 's/\<minDiskLoc\>/RecordId::min()/g' sed -i -e 's/\<maxDiskLoc\>/RecordId::max()/g' sed -i -e 's/\<getDiskLoc\>/getRecordId/g'' Changes under mmap_v1 were reverted and redone by hand as needed.
Diffstat (limited to 'src/mongo/db/storage/oplog_hack.h')
-rw-r--r--src/mongo/db/storage/oplog_hack.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/storage/oplog_hack.h b/src/mongo/db/storage/oplog_hack.h
index 8c89b3c1287..20708c1db4c 100644
--- a/src/mongo/db/storage/oplog_hack.h
+++ b/src/mongo/db/storage/oplog_hack.h
@@ -32,21 +32,21 @@
#include "mongo/base/status_with.h"
namespace mongo {
- class DiskLoc;
+ class RecordId;
class OpTime;
namespace oploghack {
/**
* Converts OpTime to a DiskLoc in an unspecified manor that is safe to use as the key to in a
* RecordStore.
*/
- StatusWith<DiskLoc> keyForOptime(const OpTime& opTime);
+ StatusWith<RecordId> keyForOptime(const OpTime& opTime);
/**
* data and len must be the arguments from RecordStore::insert() on an oplog collection.
*/
- StatusWith<DiskLoc> extractKey(const char* data, int len);
+ StatusWith<RecordId> extractKey(const char* data, int len);
} // namespace oploghack
} // namespace mongo
@@ -32,21 +32,21 @@
namespace oploghack {
/**
- * Converts OpTime to a DiskLoc in an unspecified manor that is safe to use as the key to in a
+ * Converts OpTime to a RecordId in an unspecified manor that is safe to use as the key to in a
* RecordStore.
*/